@@ -5,6 +5,13 @@ from uuid import uuid4
 from ..response import ok, error
 
 
+def _format(response):
+    response['amount'] = response['amount'] / 100
+    response['status_detail'] = 'accredited' if response['status'] == 'approved' else response['status']
+
+    return response
+
+
 class Payment:
     def __init__(self, url, private_key: str, public_key: str):
         self.url = url
@@ -50,13 +57,12 @@ class Payment:
         response = r.json()
         response['processor'] = 'decidir'
         if r.status_code < 400:
-            response['status_detail'] = 'ok decidir'
-            return ok(response)
+            return ok(_format(response))
         return error(response)
 
     def get(self, payment_id: int):
         r = requests.get(self.url + '/payments/{}'.format(payment_id), headers=self.headers)
-        return ok(r.json())
+        return ok(_format(r.json()))
 
     def search(self, filters: dict) -> dict:
         # El filter puede ser:
@@ -68,4 +74,6 @@ class Payment:
         # dateTo
         # site
         r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
-        return r.json()
+        response = r.json()
+        response['results'] = [_format(r) for r in response['results']]
+        return ok(response)
