@@ -14,7 +14,7 @@ class Refund:
 
     def create(self, payment_id: str, amount:float=None) -> dict:
         data = {
-            'amount': round(amount,2)*100
+            'amount': round(amount,2)*100 if amount else amount
         }
         r = requests.post(self.url + f'/payments/{payment_id}/refunds', headers=self.headers, data=json.dumps(data))
         return r.json()
